{$ ::ctrl.loadbalancer.description $}

- IP Address {$ ::ctrl.loadbalancer.vip_address $}
- Operating Status {$ ctrl.loadbalancer.operating_status | decode:ctrl.operatingStatus $}
- Provisioning Status {$ ctrl.loadbalancer.provisioning_status | decode:ctrl.provisioningStatus $}

Provider
  {$ ::ctrl.loadbalancer.provider $}
Admin State Up
  {$ ctrl.loadbalancer.admin_state_up | yesno $}
Floating IP Address
  {$ ctrl.loadbalancer.floating_ip.ip | noValue:('None' | translate) $}
Load Balancer ID
  {$ ::ctrl.loadbalancer.id $}
Subnet ID
  {$ ::ctrl.loadbalancer.vip_subnet_id $}
Port ID
  {$ ::ctrl.loadbalancer.vip_port_id $}
Created At
  {$ ::ctrl.loadbalancer.created_at $}
Updated At
  {$ ::ctrl.loadbalancer.updated_at $}